@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -29,8 +29,8 @@
  *  
  *****************************************************************************/
 
-#include <athenaeum/exporter.h>
-#include <athenaeum/librarymodel.h>
+#include <papyro/exporter.h>
+#include <papyro/librarymodel.h>
 
 class BibTeXExporter : public Athenaeum::Exporter
 {
