@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -52,7 +52,7 @@ namespace Athenaeum
         this->cancelled = false;
         this->network = new QNetworkAccessManager;
         QObject::connect(this->network, SIGNAL(finished(QNetworkReply *)), this, SLOT(replyFinished(QNetworkReply *)));
-        
+
         this->baseFetchURL = "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi";
         this->baseSearchURL = "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi";
     }
@@ -61,34 +61,34 @@ namespace Athenaeum
     {
         return this->working;
     }
-    
+
     void PubmedSearchPrivate::cancel()
     {
         this->cancelled = true;
     }
-    
+
     void PubmedSearchPrivate::fetchPMIDS(QString queryKey, QString webEnv)
     {
         qDebug() << "queryKey = " << queryKey;
         qDebug() << "webEnv = " << webEnv;
-        
+
         QPair<QByteArray, QByteArray> dbParam = qMakePair(QByteArray("db"), QByteArray("pubmed"));
-        //	QPair<QByteArray, QByteArray> idParam = qMakePair(QByteArray("id"), QByteArray(ids.toAscii()));
+        //	QPair<QByteArray, QByteArray> idParam = qMakePair(QByteArray("id"), QByteArray(ids.toUtf8()));
         QPair<QByteArray, QByteArray> retModeParam = qMakePair(QByteArray("retmode"), QByteArray("xml"));
-        QPair<QByteArray, QByteArray> webenvParam = qMakePair(QByteArray("WebEnv"), QByteArray(webEnv.toAscii()));
-        QPair<QByteArray, QByteArray> querykeyParam = qMakePair(QByteArray("query_key"), QByteArray(queryKey.toAscii()));
+        QPair<QByteArray, QByteArray> webenvParam = qMakePair(QByteArray("WebEnv"), QByteArray(webEnv.toUtf8()));
+        QPair<QByteArray, QByteArray> querykeyParam = qMakePair(QByteArray("query_key"), QByteArray(queryKey.toUtf8()));
         QPair<QByteArray, QByteArray> retTypeParam = qMakePair(QByteArray("rettype"), QByteArray("abstract"));
         QPair<QByteArray, QByteArray> toolParam = qMakePair(QByteArray("tool"), QByteArray("utopialibrary"));
-        
+
         QList< QPair<QByteArray, QByteArray> > paramList;
-        
+
         paramList << dbParam << retModeParam << querykeyParam << webenvParam << retTypeParam << toolParam;
-        
+
         QUrl url(this->baseFetchURL);
         url.setEncodedQueryItems(paramList);
-        
+
         qDebug() << "URL IS " << url;
-        
+
         QNetworkRequest request(url);
         this->network->get(request);
     }
@@ -97,83 +97,83 @@ namespace Athenaeum
     {
         QDomDocument efetch("EFetch Response");
         efetch.setContent(response);
-        
+
         //qDebug() << response;
-        
+
         QDomNode eFetchResultNode = efetch.firstChildElement("PubmedArticleSet");
-        
+
         if (!eFetchResultNode.isNull())
         {
             QDomElement articleSetElement = eFetchResultNode.toElement();
-            
+
             QDomNodeList articleNodeList = articleSetElement.elementsByTagName("PubmedArticle");
-            
+
             qDebug() << "There are " << articleNodeList.count() << " articles";
-            
+
             for (int articleIndex = 0 ; articleIndex < articleNodeList.count() ; ++articleIndex)
             {
                 QDomNode articleNode = articleNodeList.at(articleIndex);
                 QDomElement articleElement = articleNode.toElement();
-                
+
                 QDomNode medlineCitationNode = articleNode.firstChildElement("MedlineCitation");
-                
+
                 if (!medlineCitationNode.isNull())
                 {
                     QDomNode articleNode = medlineCitationNode.firstChildElement("Article");
-                    
+
                     if (!articleNode.isNull())
                     {
                         QString title = articleNode.firstChildElement("ArticleTitle").toElement().text();
                         QString abstract = articleNode.firstChildElement("Abstract").toElement().text();
-                        
+
                         QDomNode journalNode = articleNode.firstChildElement("Journal");
-                        
+
                         QString publicationTitle = journalNode.firstChildElement("Title").toElement().text();
                         QString publicationISOTitle = journalNode.firstChildElement("ISOAbbreviation").toElement().text();
-                        
+
                         QDomNode journalIssueNode = journalNode.firstChildElement("JournalIssue");
-                        
-                        
+
+
                         QString volume = journalIssueNode.firstChildElement("Volume").toElement().text();
                         QString issue = journalIssueNode.firstChildElement("Issue").toElement().text();
-                        
+
                         QDomNode journalPubDateNode = journalIssueNode.firstChildElement("PubDate");
                         QString year = journalPubDateNode.firstChildElement("Year").toElement().text();
                         QString month = journalPubDateNode.firstChildElement("Month").toElement().text();
                         QString day = journalPubDateNode.firstChildElement("Day").toElement().text();
-                        
+
                         QDomNode authorListNode = articleNode.firstChildElement("AuthorList");
-                        
+
                         QDomNodeList authorList = articleNode.toElement().elementsByTagName("Author");
-                        
-                        
+
+
                         this->model->insertRow(this->model->rowCount());
                         QModelIndex index(this->model->index(this->model->rowCount() - 1, 0));
-                        
+
                         this->model->setTitle(index, title);
                         this->model->setPublicationTitle(index, publicationTitle);
                         this->model->setVolume(index, volume);
                         this->model->setYear(index, year);
                         this->model->setAbstract(index, abstract);
 
-     
-                        
+
+
                         QList< QPair< QStringList, QStringList > > authors;
-                        
+
                         for (int authorIndex = 0 ; authorIndex < authorList.count(); ++ authorIndex)
                         {
                             QDomNode authorNode = authorList.at(authorIndex);
                             QString foreName = authorNode.firstChildElement("ForeName").toElement().text();
                             QString lastName = authorNode.firstChildElement("LastName").toElement().text();
-                            
+
                             //qDebug() << "Author : " << foreName << " " << lastName;
-                            
+
                             QStringList authorFamily = lastName.split(" ");
                             QStringList authorGiven = foreName.split(" ");
-                            
+
                             authors.append(qMakePair(authorGiven, authorFamily));
                         }
-                        
+
                         this->model->setAuthors(index, authors);
                         QString key = this->model->key(index);
                         if (key.isEmpty())
@@ -185,10 +185,10 @@ namespace Athenaeum
                         else
                         {
                             // FIXME : Scan for duplicates
-                            
+
                             this->model->setKey(index, key);
                         }
-                        
+
                         //qDebug() << abstract;
                     }
                     else
@@ -196,29 +196,29 @@ namespace Athenaeum
                         qDebug() << "disaster";
                         exit(1);
                     }
-                    
+
                 }
-                
+
                 QDomNode pubmedNode = articleNode.firstChildElement("PubmedData");
-                
+
                 if (!pubmedNode.isNull())
                 {
                     QDomNode articleIDNode = pubmedNode.firstChildElement("ArticleIdList");
-                    
+
                     QDomNodeList idList = articleIDNode.toElement().elementsByTagName("ArticleId");
                     for (int idIndex = 0 ; idIndex < idList.count() ; ++idIndex)
                     {
                         QDomElement idElement = idList.at(idIndex).toElement();
                         QString id = idElement.text();
                         //qDebug() << idElement.attribute("IdType") << " : " << id;
-                        
+
                     }
                 }
                 else
                 {
                     qDebug() << "No PubmedData";
                 }
-                
+
                 //qDebug() << "\n\n";
             }
             return articleNodeList.count();
@@ -227,20 +227,20 @@ namespace Athenaeum
         {
             qDebug() << "Got dodgy results (2)";
         }
-        
+
         return -1;
     }
 
     int PubmedSearchPrivate::parseESearchResponse(QString response)
     {
-        
+
         //qDebug() << response;
         //qDebug() << "\n\n\n";
         QDomDocument esearch("ESearch Response");
         esearch.setContent(response);
-        
+
         QDomNode eSearchResultNode = esearch.firstChildElement("eSearchResult");
-        
+
         if (!eSearchResultNode.isNull())
         {
             QDomNode countNode = eSearchResultNode.firstChildElement("Count");
@@ -248,15 +248,15 @@ namespace Athenaeum
             QDomNode webenvNode = eSearchResultNode.firstChildElement("WebEnv");
             //		QDomNode retMaxNode = eSearchResultNode.firstChildElement("RetMax");
             //		QDomNode retStartNode = eSearchResultNode.firstChildElement("RetStart");
-            
+
             QDomElement countElement = countNode.toElement();
             QDomElement queryKeyElement = queryKeyNode.toElement();
             QDomElement webenvElement = webenvNode.toElement();
             //		QDomElement retMaxElement = retMaxNode.toElement();
             //		QDomElement retStartElement = retStartNode.toElement();
-            
+
             qDebug() << "Returned " << countElement.text() << " results";
-           
+
             if (countElement.text().toInt() != 0)
             {
                 this->fetchPMIDS(queryKeyElement.text(), webenvElement.text());
@@ -273,7 +273,7 @@ namespace Athenaeum
     void PubmedSearchPrivate::replyFinished(QNetworkReply *reply)
     {
         qDebug() << "got reply to " << reply->request().url().path();
-        
+
         if (this->cancelled)
         {
             qDebug() << "Search was cancelled, stopping.";
@@ -282,11 +282,11 @@ namespace Athenaeum
             emit terminated(model);
             return;
         }
-        
+
         if (reply->error() == QNetworkReply::NoError)
         {
             qDebug() << "No error";
-            
+
             if (reply->request().url().path() == "/entrez/eutils/esearch.fcgi")
             {
                 QIODevice *result = reply;
@@ -307,7 +307,7 @@ namespace Athenaeum
                 QIODevice *result = reply;
                 QByteArray res = result->readAll();
                 QString xmlstring = res;
-                
+
                 int results = this->parseEFetchResponse(res);
                 emit fetchComplete(model, results);
             }
@@ -316,7 +316,7 @@ namespace Athenaeum
                 this->working = false;
                 qFatal("Unrecognised response");
                 exit(1);
-                
+
             }
         }
         else
@@ -325,20 +325,20 @@ namespace Athenaeum
             this->working = false;
             emit terminated(model);
         }
-        
+
     }
 
     void PubmedSearchPrivate::sendQuery(QList< QList < QString > > clauses, bool matchAll)
     {
         this->working = true;
-        
+
         // Basic Pubmed query creation
-        
+
         QString query;
         for (int i = 0; i < clauses.count(); ++i)
         {
             qDebug() << "Clause: " << clauses.at(i);
-            
+
             QString clauseQuery;
             if (clauses.at(i).at(1).compare("does not contain") == 0)
             {
@@ -350,9 +350,9 @@ namespace Athenaeum
             clauseQuery += "[";
             clauseQuery += clauses.at(i).at(0);
             clauseQuery += "]";
-            
+
             query += clauseQuery;
-            
+
             if (i < clauses.count() - 1)
             {
                 if (matchAll)
@@ -364,11 +364,11 @@ namespace Athenaeum
                     query += " OR ";
                 }
             }
-        }    
-        
+        }
+
         QPair<QByteArray, QByteArray> dbParam = qMakePair(QByteArray("db"), QByteArray("pubmed"));
         QPair<QByteArray, QByteArray> termParam = qMakePair(QByteArray("term"), QUrl::toPercentEncoding(query));
-        
+
         // don't need to actually return any PMIDs, since we use the WebEnv environment to retrieve
         // them at the eSearch level. So for now, ask for 0 results to keep this lump of XML
         // as small as possible
@@ -376,14 +376,14 @@ namespace Athenaeum
         QPair<QByteArray, QByteArray> retmaxParam = qMakePair(QByteArray("retmax"), QByteArray("0"));
         QPair<QByteArray, QByteArray> toolParam = qMakePair(QByteArray("tool"), QByteArray("utopialibrary"));
         QPair<QByteArray, QByteArray> historyParam = qMakePair(QByteArray("usehistory"), QByteArray("y"));
-        
+
         QList< QPair<QByteArray, QByteArray> > paramList;
-        
+
         paramList << dbParam << termParam << retstartParam << retmaxParam << toolParam << historyParam;
-        
+
         QUrl url(this->baseSearchURL);
         url.setEncodedQueryItems(paramList);
-        
+
         QNetworkRequest request(url);
         this->network->get(request);
     }
@@ -398,7 +398,7 @@ namespace Athenaeum
         if (this->parentObject == 0)
         {
             this->parentObject = parent;
-            
+
             connect(this, SIGNAL(fetchComplete(LibraryModel *, int)), parent, SLOT(completed(LibraryModel *, int)));
             connect(this, SIGNAL(searchComplete(LibraryModel *, int)), parent, SLOT(partCompleted(LibraryModel *, int)));
             connect(this, SIGNAL(terminated(LibraryModel *)), parent, SLOT(terminated(LibraryModel *)));
@@ -421,17 +421,17 @@ namespace Athenaeum
     {
         return p->busy();
     }
-    
+
     void PubmedSearch::cancel()
     {
         p->cancel();
     }
-    
+
     QString PubmedSearch::name() const
     {
         return "Pubmed";
     }
-    
+
     void PubmedSearch::sendQuery(QList< QList < QString > > clauses, bool matchAll)
     {
         p->sendQuery(clauses, matchAll);
