@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -35,7 +35,7 @@
 class RISImporter : public Athenaeum::Importer
 {
 public:
-    bool import(Athenaeum::AbstractBibliographicModel * model, QIODevice * io);
+    bool import(Athenaeum::AbstractBibliography * model, QIODevice * io);
     QStringList extensions() const;
     QString name() const;
     bool supports(QIODevice * io) const;
