@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -83,7 +83,7 @@ namespace CINEMA6
 
     bool AbstractComponent::event(QEvent * event)
     {
-        if (AlignmentView * av = alignmentView())
+        if (/* AlignmentView * av = */ alignmentView())
         {
             switch (event->type())
             {
