@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -87,6 +87,12 @@ namespace CINEMA6
         virtual void mouseReleaseEvent(Component * component, QMouseEvent * event);
 
     private:
+
+        using AbstractComponent::mouseDoubleClickEvent;
+        using AbstractComponent::mouseMoveEvent;
+        using AbstractComponent::mousePressEvent;
+        using AbstractComponent::mouseReleaseEvent;
+
         boost::scoped_ptr< AspectPrivate > d;
 
     }; // class Aspect
