@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -124,7 +124,7 @@ namespace CINEMA6
         // Get colour
         QColor & color(const QChar & code)
             {
-                return this->_colourmap[code.toAscii()];
+                return this->_colourmap[code.toLatin1()];
             }
 
     private:
