@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -35,8 +35,6 @@
 #include <graffiti/config.h>
 #include <QStyledItemDelegate>
 
-class QCDEStyle;
-
 namespace Graffiti
 {
 
@@ -50,8 +48,6 @@ namespace Graffiti
         void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
 
     protected:
-        QCDEStyle *_cdeStyle;
-
         TableWidget *_tableWidget;
     };
 
