@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -36,8 +36,6 @@
 
 #include <QTableView>
 
-class QtColorPicker;
-
 namespace Graffiti
 {
 
@@ -56,6 +54,7 @@ namespace Graffiti
         void colourChanged(QModelIndex modelIndex, QColor colour);
         void checkChanged(QModelIndex modelIndex);
         void dataChanged();
+        void dataChanged(const QModelIndex &, const QModelIndex &, const QVector<int> &);
 
 
 
@@ -68,9 +67,6 @@ namespace Graffiti
 
     protected:
         void mousePressEvent(QMouseEvent * event);
-        QtColorPicker *_colourPicker;
-        QtColorPicker *_typePicker;
-
         TableWidget *_tableWidget;
 
     };
