@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -32,10 +32,10 @@
 #ifndef PAPYRO_ANNOTATIONPROCESSORACTION_H
 #define PAPYRO_ANNOTATIONPROCESSORACTION_H
 
-#include <spine/Annotation.h>
-#include <spine/Document.h>
-
-#include <boost/shared_ptr.hpp>
+#if !defined(Q_MOC_RUN) || QT_VERSION >= 0x050000
+#  include <spine/Annotation.h>
+#  include <spine/Document.h>
+#endif
 
 #include <QAction>
 #include <QPointer>
