@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -32,11 +32,12 @@
 #ifndef PAPYRO_CAPABILITY_H
 #define PAPYRO_CAPABILITY_H
 
-#include <boost/scoped_ptr.hpp>
-
-#include <boost/shared_ptr.hpp>
-#include <boost/weak_ptr.hpp>
-#include <spine/Capability.h>
+#if !defined(Q_MOC_RUN) || QT_VERSION >= 0x050000
+#  include <boost/scoped_ptr.hpp>
+#  include <boost/shared_ptr.hpp>
+#  include <boost/weak_ptr.hpp>
+#  include <spine/Capability.h>
+#endif
 
 #include <QPixmap>
 #include <QString>
