@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -34,10 +34,12 @@
 
 #include <papyro/config.h>
 
-#include <spine/Annotation.h>
 #include <utopia2/qt/abstractcommentdata.h>
 
-#include <boost/scoped_ptr.hpp>
+#if !defined(Q_MOC_RUN) || QT_VERSION >= 0x050000
+#  include <spine/Annotation.h>
+#  include <boost/scoped_ptr.hpp>
+#endif
 
 namespace Papyro
 {
