@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -35,7 +35,10 @@
 #include <utopia2/networkaccessmanager.h>
 #include <utopia2/auth/service.h>
 #include <utopia2/auth/servicemanager.h>
-#include <spine/Document.h>
+
+#if !defined(Q_MOC_RUN) || QT_VERSION >= 0x050000
+#  include <spine/Document.h>
+#endif
 
 #include <QList>
 #include <QMap>
