@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -32,10 +32,12 @@
 #ifndef PAPYRO_SELECTIONPROCESSOR_H
 #define PAPYRO_SELECTIONPROCESSOR_H
 
-#include <boost/shared_ptr.hpp>
 #include <papyro/abstractprocessor.h>
 #include <papyro/config.h>
-#include <spine/Document.h>
+#if !defined(Q_MOC_RUN) || QT_VERSION >= 0x050000
+#  include <boost/shared_ptr.hpp>
+#  include <spine/Document.h>
+#endif
 #include <utopia2/extension.h>
 
 #include <QIcon>
