@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -33,10 +33,13 @@
 #define PAPYRO_TABBAR_P_H
 
 #include <papyro/papyrotab.h>
+#include <papyro/citation.h>
 
+#include <QIcon>
 #include <QObject>
 #include <QPixmap>
 #include <QMap>
+#include <QSignalMapper>
 #include <QTime>
 #include <QTimer>
 #include <QUrl>
@@ -46,7 +49,8 @@ namespace Papyro
 
     typedef struct TabData
     {
-        QObject * target;
+        PapyroTab * tab;
+        Athenaeum::CitationHandle citation;
         QString title;
         int size;
         int offset;
@@ -54,6 +58,8 @@ namespace Papyro
         bool error;
         QTime time;
         qreal progress;
+        bool starred;
+        bool known;
     } TabData; // struct TabData
 
 
@@ -72,13 +78,13 @@ namespace Papyro
 
         // Interaction state
         int currentIndex;
-        QList< TabData > targets;
+        QList< TabData > tabs;
+        QSignalMapper citationMapper;
 
         // Render options
-        QPixmap activeImage;
-        QPixmap inactiveImage;
-        QPixmap hoverImage;
-        int assetScale;
+        QSize tabCurveSize;
+        QIcon closeButtonIcon;
+        QIcon starButtonIcon;
         int tabEdgeSize;
         int minTabSize;
         int maxTabSize;
@@ -88,6 +94,9 @@ namespace Papyro
         int tabMargin;
         int spinnerSize;
 
+        int actionLeft() const;
+        int tabLeft() const;
+
         // Render state
         int extent; // total height of all tabs
         int position; // current scroll position
@@ -95,16 +104,29 @@ namespace Papyro
 
         // Mouse state
         QPoint hoverPos;
-        int tabUnderMouse;
-        int tabButtonPressed;
-        int tabButtonUnderMouse;
-        void updateHoverPos(const QPoint & pos);
+        int tabCloseButtonPressed;
+        int tabCloseButtonUnderMouse;
+        int tabStarButtonPressed;
+        int tabStarButtonUnderMouse;
+        struct {
+            struct {
+                int tab;
+                int section;
+            } move;
+            struct {
+                int section;
+            } press;
+        } mouse;
         QTimer wheelDelay;
 
+        // Hi DPI scaling
+        qreal dpiScaling;
+
         int getCurrentIndex() const;
         int getPosition() const;
         int getTabOffset(int index) const;
-        QRect getTabButtonRect(int index) const;
+        QRect getTabCloseButtonRect(int index) const;
+        QRect getTabStarButtonRect(int index) const;
         QRect getTabRect(int index) const;
         QRect getTabRect(const TabData * data) const;
         int getTabSize(int index) const;
@@ -112,17 +134,25 @@ namespace Papyro
         int tabAt(const QPoint & pos) const;
         TabData * tabData(int index);
         const TabData * tabData(int index) const;
-        const TabData * tabData(QObject * target) const;
+        const TabData * tabData(QObject * tab) const;
         const TabData * tabDataAt(const QPoint & pos) const;
         void toggleAnimationTimer();
         void updateGeometries();
+        void updateState(TabData * data);
+
+    signals:
+        void closeRequested(int index);
 
     public slots:
-        void removeTarget(QObject * target);
-        void targetProgressChanged(qreal progress);
-        void targetStateChanged(PapyroTab::State progress);
-        void targetTitleChanged(const QString & title);
-        void targetUrlChanged(const QUrl & url);
+        void tabCloseRequested();
+        void tabDestroyed(QObject * obj);
+        void tabProgressChanged(qreal progress);
+        void tabStateChanged(PapyroTab::State progress);
+        void tabTitleChanged(const QString & title);
+        void tabUrlChanged(const QUrl & url);
+        void onCitationChanged(QObject * tab);
+        void onTabCitationChanged();
+        void updateHoverPos();
     };
 
 }
