@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -66,7 +66,7 @@ void HighlightFactory::processSelection(Spine::DocumentHandle document, Spine::C
     foreach (Spine::TextExtentHandle extent, document->textSelection()) {
         annotation->addExtent(extent);
     }
-    document->addAnnotation(annotation);
+    document->addAnnotation(annotation, "PersistQueue");
     document->clearSelection();
 }
 
