@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -49,9 +49,11 @@ public:
     void activate(Spine::DocumentHandle document, Spine::AnnotationSet annotations, const QPoint & globalPos = QPoint());
     bool canActivate(Spine::DocumentHandle document, Spine::AnnotationHandle annotation) const;
     int category() const;
+    using Papyro::AnnotationProcessor::icon;
     QIcon icon() const;
     void processSelection(Spine::DocumentHandle document, Spine::CursorHandle cursor, const QPoint & globalPos = QPoint());
     QList< boost::shared_ptr< Papyro::SelectionProcessor > > selectionProcessors(Spine::DocumentHandle document, Spine::CursorHandle cursor);
+    using Papyro::AnnotationProcessor::title;
     QString title() const;
     QString title(Spine::DocumentHandle document, Spine::AnnotationHandle annotation) const;
     int weight() const;
