@@ -1,7 +1,7 @@
 ###############################################################################
 #   
 #    This file is part of the Utopia Documents application.
-#        Copyright (c) 2008-2014 Lost Island Labs
+#        Copyright (c) 2008-2016 Lost Island Labs
 #            <info@utopiadocs.com>
 #    
 #    Utopia Documents is free software: you can redistribute it and/or modify
@@ -34,7 +34,7 @@
 #? urls: http://rest.kegg.jp/
 
 
-import common.utils
+import utopialib.utils
 import re
 import socket
 import spineapi
@@ -52,7 +52,7 @@ class ASPBDatabaseLookups(utopia.document.Annotator, utopia.document.Visualiser)
 
     @utopia.document.buffer
     def on_ready_event(self, document):
-        doi = common.utils.metadata(document, 'doi', '')
+        doi = utopialib.utils.metadata(document, 'identifiers[doi]')
 
         # Find and aggregate AGI instances in the document
         matches_by_agi = {}
@@ -77,12 +77,13 @@ class ASPBDatabaseLookups(utopia.document.Annotator, utopia.document.Visualiser)
                 annotation['property:name'] = 'Plant gene databases'
                 annotation['property:description'] = 'American Society of Plant Biologists'
                 annotation['property:sourceIcon'] = utopia.get_plugin_data_as_url('images/aspb_logo.png', 'image/png')
-                if doi.startswith('10.1104/'):
-                    annotation['property:sourceIcon'] = utopia.get_plugin_data_as_url('images/pp_logo.png', 'image/png')
-                    annotation['property:description'] = 'From Plant Physiology'
-                elif doi.startswith('10.1105/'):
-                    annotation['property:sourceIcon'] = utopia.get_plugin_data_as_url('images/tpc_logo.png', 'image/png')
-                    annotation['property:description'] = 'From Plant Cell'
+                if doi is not None:
+                    if doi.startswith('10.1104/'):
+                        annotation['property:sourceIcon'] = utopia.get_plugin_data_as_url('images/pp_logo.png', 'image/png')
+                        annotation['property:description'] = 'From Plant Physiology'
+                    elif doi.startswith('10.1105/'):
+                        annotation['property:sourceIcon'] = utopia.get_plugin_data_as_url('images/tpc_logo.png', 'image/png')
+                        annotation['property:description'] = 'From Plant Cell'
                 annotation['property:sourceDescription'] = '''
                   <p>
                     The <a href="http://www.aspb.org/">American Society of Plant Biologists</a>
