@@ -1,7 +1,7 @@
 ###############################################################################
 #   
 #    This file is part of the Utopia Documents application.
-#        Copyright (c) 2008-2014 Lost Island Labs
+#        Copyright (c) 2008-2016 Lost Island Labs
 #            <info@utopiadocs.com>
 #    
 #    Utopia Documents is free software: you can redistribute it and/or modify
@@ -34,7 +34,7 @@
 #? urls: http://crossmark.crossref.org/
 
 
-import common.utils
+import utopialib.utils
 import json
 import random
 import spineapi
@@ -61,7 +61,7 @@ class CrossMarkAnnotator(utopia.document.Annotator):
         # See if there is any CrossMark information available for this document
 
         # Firstly find the document's DOI
-        doi = common.utils.metadata(document, 'doi')
+        doi = utopialib.utils.metadata(document, 'identifiers[doi]')
         if doi is not None:
 
             # Then attempt to access CrossMark API
