@@ -1,7 +1,7 @@
 ###############################################################################
 #   
 #    This file is part of the Utopia Documents application.
-#        Copyright (c) 2008-2014 Lost Island Labs
+#        Copyright (c) 2008-2016 Lost Island Labs
 #            <info@utopiadocs.com>
 #    
 #    Utopia Documents is free software: you can redistribute it and/or modify
@@ -34,7 +34,7 @@
 #? urls: http://beta.sciencewise.info/ http://sciencewise.info/
 
 
-import common.utils
+import utopialib.utils
 import hashlib
 import json
 import spineapi
