@@ -1,7 +1,7 @@
 ###############################################################################
 #   
 #    This file is part of the Utopia Documents application.
-#        Copyright (c) 2008-2014 Lost Island Labs
+#        Copyright (c) 2008-2016 Lost Island Labs
 #            <info@utopiadocs.com>
 #    
 #    Utopia Documents is free software: you can redistribute it and/or modify
@@ -34,7 +34,7 @@
 #? urls: http://www.sherpa.ac.uk/
 
 
-import common.utils
+import utopialib.utils
 import json
 import re
 import socket
@@ -50,8 +50,8 @@ class SherpaRomeo(utopia.document.Annotator, utopia.document.Visualiser):
     apiKey = 'TGb5fUBjk9Q'
 
     def on_ready_event(self, document):
-        issn = common.utils.metadata(document, 'issn')
-        doi = common.utils.metadata(document, 'doi')
+        issn = utopialib.utils.metadata(document, 'publication-issn')
+        doi = utopialib.utils.metadata(document, 'identifiers[doi]')
         if issn is not None:
             params = {
                 'versions': 'all',
