@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -29,8 +29,6 @@
  *  
  *****************************************************************************/
 
-#include "raptor_init.h"
-#include "utopia_serializer.h"
 #include "utopia_parser.h"
 
 #include <utopia2/extension.h>
@@ -57,6 +55,4 @@ extern "C" API_EXPORT const char * utopia_description()
 extern "C" API_EXPORT void utopia_registerExtensions()
 {
     UTOPIA_REGISTER_EXTENSION(Utopia::UTOPIAParser);
-    UTOPIA_REGISTER_EXTENSION(Utopia::UTOPIASerializer);
-    UTOPIA_REGISTER_EXTENSION(Utopia::RaptorInit);
 }
