@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -98,9 +98,9 @@ namespace Utopia
         inline void* librarySymbol(void * handle_, const QString & name_)
         {
 #ifdef _WIN32
-            return (void*) GetProcAddress((HMODULE) handle_, name_.toAscii().constData());
+            return (void*) GetProcAddress((HMODULE) handle_, name_.toUtf8().constData());
 #else
-            return ::dlsym(handle_, name_.toAscii().constData());
+            return ::dlsym(handle_, name_.toUtf8().constData());
 #endif
         }
 
