@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -389,6 +389,6 @@ namespace Utopia
 
 } /* namespace Utopia */
 
-Q_DECLARE_METATYPE(Utopia::Node*)
+Q_DECLARE_METATYPE(Utopia::Node*);
 
 #endif /* Utopia_NODE_H */
