@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -38,8 +38,6 @@
 
 #include <QObject>
 
-class QUuid;
-
 namespace Utopia
 {
 
@@ -52,7 +50,7 @@ namespace Utopia
         QStringList paths() const;
         QList< Plugin * > plugins() const;
         bool remove(Plugin * plugin);
-        Plugin * resolve(Plugin::PluginBase base, const QString & relativePath);
+        Plugin * resolve(const QFileInfo & fileInfo);
         Plugin * resolve(const QUuid & uuid);
 
         static boost::shared_ptr< PluginManager > instance();
