@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -38,7 +38,7 @@
 #include <QColor>
 #include <QDebug>
 
-Q_DECLARE_METATYPE(QPointer< Kend::Service >)
+Q_DECLARE_METATYPE(QPointer< Kend::Service >);
 
 namespace Kend
 {
@@ -211,8 +211,8 @@ namespace Kend
                     v = (int) (col == 3 ? Qt::AlignRight : Qt::AlignLeft) | Qt::AlignVCenter;
                     break;
                 case Qt::ForegroundRole:
-                    v = (s->serviceState() == Service::StoppedState ||
-                         s->serviceState() == Service::ErrorState) ? Qt::gray : Qt::black;
+                    v = QColor((s->serviceState() == Service::StoppedState ||
+                         s->serviceState() == Service::ErrorState) ? Qt::gray : Qt::black);
                     break;
                 case ServiceRole:
                     v = QVariant::fromValue< QPointer< Service > >(s);
