@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -37,8 +37,6 @@
 
 #include <boost/shared_ptr.hpp>
 
-#include <qjson/parser.h>
-
 #include <QDateTime>
 #include <QMap>
 #include <QObject>
@@ -96,9 +94,6 @@ namespace Kend
         QPixmap avatar;
         QPixmap avatarOverlay;
 
-        // Helper
-        QJson::Parser jsonParser;
-
         // Modify this user's information
         bool isModified(bool includeAvatar = true) const;
         void removeValue(const QString & key);
