@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -101,7 +101,7 @@ namespace Utopia
         bool ascii = true;
         for (int i = 0; ascii && i < binaryCheckString.size(); ++i)
         {
-            ascii = ascii && binaryCheckString.at(i).toAscii();
+            ascii = ascii && binaryCheckString.at(i).toLatin1();
         }
 
         if (ascii)
