@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -49,7 +49,7 @@ namespace Utopia
         PreferencesDialog(QWidget * parent = 0, Qt::WindowFlags f = 0);
         ~PreferencesDialog();
 
-        bool focusPane(const QString & paneName);
+        bool focusPane(const QString & paneName, const QVariant & params = QVariant());
 
         static boost::shared_ptr< PreferencesDialog > instance();
         static QMessageBox::Button requestModifiedAction(const QString & message = QString(), QWidget * parent = 0);
