@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -39,8 +39,9 @@
 namespace Utopia
 {
 
-    struct ProgressDialogPrivate
+    class ProgressDialogPrivate
     {
+    public:
         QLabel * label;
         Spinner * spinner;
         QTimer timer;
