@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -62,6 +62,8 @@ namespace Utopia
         connect(&timeLine, SIGNAL(valueChanged(qreal)), this, SLOT(animate(qreal)));
         connect(&timeLine, SIGNAL(finished()), this, SLOT(animationFinished()));
         connect(this, SIGNAL(animated()), layout, SIGNAL(animated()));
+        connect(this, SIGNAL(widgetChanged(QWidget *)), layout, SIGNAL(widgetChanged(QWidget *)));
+
     }
 
     void SlideLayoutPrivate::animate(qreal value)
@@ -154,6 +156,8 @@ namespace Utopia
                     animationFinished();
                 }
             }
+
+            emit widgetChanged(toPage);
         }
     }
 
