@@ -1,7 +1,7 @@
 /*****************************************************************************
  *  
  *   This file is part of the Utopia Documents application.
- *       Copyright (c) 2008-2014 Lost Island Labs
+ *       Copyright (c) 2008-2016 Lost Island Labs
  *           <info@utopiadocs.com>
  *   
  *   Utopia Documents is free software: you can redistribute it and/or modify
@@ -71,7 +71,7 @@ namespace Utopia
 
         painter->save();
         painter->setRenderHint(QPainter::TextAntialiasing);
-        QFontMetrics fm = painter->font();
+        QFontMetrics fm = painter->fontMetrics();
 
         painter->setPen(Qt::black);
         painter->setBrush(QColor(0,0,0,0));
